<?php

namespace Crm\Customer\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Crm\Customer\Http\Resources\CustomerResource;
use Crm\Customer\Http\Resources\CustomersCollection;
use Crm\Customer\Scopes\WebsitePublicScope;
use Crm\Customer\Models\Website;

class WebsitePublicController extends BaseController
{

    /**
     * Show website's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Website::pushScope(new RequestScope())
            ->pushScope(new WebsitePublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $websites = new WebsitesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('customer::website.names'))
            ->view('customer::public.website.index')
            ->data(compact('websites', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show website.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Website::findBySlug($slug);
        $data = new WebsiteResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('customer::website.name'))
            ->view('customer::public.website.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
