<?php

namespace Crm\Customer\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Customer\Events\CustomerAction as CustomerActionEvent;
use Crm\Customer\Notifications\CustomerAction as CustomerActionNotification;
use Litepie\Actions\Concerns\AsAction;

class CustomerAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the CustomerActionEvent.
     *
     * @param   CustomerActionEvent  $event
     * @return mixed
     */
    public function handle(CustomerActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $customer.
     *
     * @param   CustomerActionEvent  $event
     * @return void
     */
    public function create(CustomerActionEvent $event)
    {
        $client = $event->customer->client;
        Notification::send($client, new CustomerActionNotification($event));
    }

    /**
     * Handle the CustomerActionEvent as a listener.
     *
     * @param   CustomerActionEvent  $event
     * @return mixed
     */
    public function asListener(CustomerActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   CustomerActionEvent  $event
     * @return bool
     */
    private function isAllowed(CustomerActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
