<?php

namespace Crm\Customer\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Crm\Customer\Events\WebsiteAction as WebsiteActionEvent;
use Crm\Customer\Notifications\WebsiteAction as WebsiteActionNotification;
use Litepie\Actions\Concerns\AsAction;

class WebsiteAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the WebsiteActionEvent.
     *
     * @param   WebsiteActionEvent  $event
     * @return mixed
     */
    public function handle(WebsiteActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $website.
     *
     * @param   WebsiteActionEvent  $event
     * @return void
     */
    public function create(WebsiteActionEvent $event)
    {
        $client = $event->website->client;
        Notification::send($client, new WebsiteActionNotification($event));
    }

    /**
     * Handle the WebsiteActionEvent as a listener.
     *
     * @param   WebsiteActionEvent  $event
     * @return mixed
     */
    public function asListener(WebsiteActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   WebsiteActionEvent  $event
     * @return bool
     */
    private function isAllowed(WebsiteActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
