<?php

namespace Crm\Customer\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\Customer\Models\Customer;

class CustomerPolicy
{


    /**
     * Determine if the given user can view the customer.
     *
     * @param Authenticatable $user
     * @param Customer $customer
     *
     * @return bool
     */
    public function view(Authenticatable $user, Customer $customer)
    {
        if ($authUser->canDo('customer.customer.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $customer->is_owner;
    }

    /**
     * Determine if the given user can create a customer.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('customer.customer.create');
    }

    /**
     * Determine if the given user can update the given customer.
     *
     * @param Authenticatable $user
     * @param Customer $customer
     *
     * @return bool
     */
    public function update(Authenticatable $user, Customer $customer)
    {
        if ($user->canDo('customer.customer.edit') && $user->isAdmin()) {
            return true;
        }

        return $customer->is_owner;
    }

    /**
     * Determine if the given user can delete the given customer.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Customer $customer)
    {
        return $customer->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
