<?php

namespace Crm\Customer\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Crm\Customer\Models\Website;

class WebsitePolicy
{


    /**
     * Determine if the given user can view the website.
     *
     * @param Authenticatable $user
     * @param Website $website
     *
     * @return bool
     */
    public function view(Authenticatable $user, Website $website)
    {
        if ($authUser->canDo('customer.website.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $website->is_owner;
    }

    /**
     * Determine if the given user can create a website.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('customer.website.create');
    }

    /**
     * Determine if the given user can update the given website.
     *
     * @param Authenticatable $user
     * @param Website $website
     *
     * @return bool
     */
    public function update(Authenticatable $user, Website $website)
    {
        if ($user->canDo('customer.website.edit') && $user->isAdmin()) {
            return true;
        }

        return $website->is_owner;
    }

    /**
     * Determine if the given user can delete the given website.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Website $website)
    {
        return $website->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
